@@ -262,8 +262,8 @@ class VariableClChrootStatus(ReadonlyVariable):
         if not os.access('/proc/self/mountinfo', R_OK) or \
                 not os.access('/proc/1/mountinfo', R_OK):
             return False
-        infos = [open(x, 'r').read() for x in ('/proc/1/mountinfo',
-                                               '/proc/self/mountinfo')]
+        infos = [readFile(x) for x in ('/proc/1/mountinfo',
+                                       '/proc/self/mountinfo')]
         return infos[0] != infos[1]
 
     def get(self):
